@@ -13,11 +13,9 @@ class TubeMapDisplay(QtGui.QMainWindow):
         #self.ui.labelTubeMap.setText("Hello")
         self.pic = QtGui.QLabel(self)
         self.pic.setGeometry(0,0,800,400)
-        self.pic.setPixmap(QtGui.QPixmap(os.getcwd() + "/tubemap.gif"))
+        #self.pic.setPixmap(QtGui.QPixmap(os.getcwd() + "/tubemap.gif"))
+        self.pic.setPixmap(QtGui.QPixmap("/opt/tflapp/tubemap.gif"))
         self.scrollArea = QtGui.QScrollArea(self)
         self.scrollArea.setWidget(self.pic)
         self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 400))
         self.scrollArea.setWidgetResizable(True)
-        #self.scrollArea.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        #self.scrollArea.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-        #self.scrollArea.show()
